<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
use PHPUnit\Framework\TestCase;

final class Issue5210Test extends TestCase
{
    protected function tearDown(): void
    {
        throw new Exception('test');
    }

    public function testOne(): void
    {
        $this->assertTrue(true);
    }
}
